package fyloz.trial.ColorRecipesExplorer.web.controller.removers;

import fyloz.trial.ColorRecipesExplorer.model.Company;
import fyloz.trial.ColorRecipesExplorer.services.CompanyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;

import static fyloz.trial.ColorRecipesExplorer.web.PagesPaths.REMOVER_COMPANY;
import static fyloz.trial.ColorRecipesExplorer.web.PagesPaths.REMOVER_COMPANY_SPECIFIC;
import static fyloz.trial.ColorRecipesExplorer.web.StringBank.*;

@Controller
public class CompanyRemoverController {

    private CompanyService companyService;

    @Autowired
    public CompanyRemoverController(CompanyService companyService) {
        this.companyService = companyService;
    }

    /**
     * Affiche la page listant toutes les bannières.
     * <p>
     * Modèle de la page:
     * - companies: Contient la liste de toutes les bannières
     *
     * @param model Le Model injecté par Thymeleaf
     * @return La page à afficher
     */
    @GetMapping(REMOVER_COMPANY)
    public String showPage(Model model) {
        model.addAttribute(COMPANIES, companyService.getAll());

        return REMOVER_COMPANY;
    }

    /**
     * Permet à l'utilisateur de supprimer une bannière.
     * La méthode requiert l'identifiant de la bannière à supprimer dans l'URL.
     * <p>
     * La suppression échouera si:
     * - L'utilisateur n'est pas autorisé à exécuter cette action
     * - Il n'y a aucune bannière avec cet identifiant
     * - La bannière est associée à une ou plusieurs recettes
     * <p>
     * Modèle de la page:
     * - error: Contient le message d'erreur, s'il y a lieu
     * - successCompanyName: Contient le nom de la bannière supprimée
     * <p>
     * REQUIERT UNE AUTORISATION
     *
     * @param model     Le Model injecté par Thymeleaf
     * @param companyID L'identifiant de la bannière
     * @return La page à afficher
     */

    @PostMapping(REMOVER_COMPANY_SPECIFIC)
    public String removeCompany(Model model, @PathVariable int companyID) {
        Company company = companyService.getByID(companyID);
        if (companyService.exists(company)) {
            if (companyService.deleteIfNotLinked(company)) {
                model.addAttribute("successCompanyName", company.getCompanyName());
            } else {
                model.addAttribute(RESPONSE_ERROR, String.format(COMPANY_LINKED, company.getCompanyName()));
            }
        } else {
            model.addAttribute(RESPONSE_ERROR, String.format(COMPANY_NOT_FOUND, companyID));
        }

        return showPage(model);
    }
}
