package fyloz.trial.ColorRecipesExplorer.web.controller.removers;

import fyloz.trial.ColorRecipesExplorer.model.Recipe;
import fyloz.trial.ColorRecipesExplorer.services.RecipeService;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;

import static fyloz.trial.ColorRecipesExplorer.web.PagesPaths.REMOVER_RECIPE;
import static fyloz.trial.ColorRecipesExplorer.web.PagesPaths.REMOVER_RECIPE_SPECIFIC;
import static fyloz.trial.ColorRecipesExplorer.web.StringBank.*;

@Controller
public class RecipeRemoverController {

    private RecipeService recipeService;

    public RecipeRemoverController(RecipeService recipeService) {
        this.recipeService = recipeService;
    }

    /**
     * Affiche la liste de toutes les recettes.
     *
     * @param model Le Model injecté par Thymeleaf
     * @return La page à afficher.
     */
    @GetMapping(REMOVER_RECIPE)
    public String listRecipes(Model model) {
        model.addAttribute(RECIPES, recipeService.getRecipesByCompany());

        return REMOVER_RECIPE;
    }

    /**
     * Permet à l'utilisateur de supprimer une recette.
     * Cette méthode requiert l'identifiant de la recette dans l'URL.
     * <p>
     * La suppression échouera si:
     * - L'utilisateur n'est pas autorisé à exécuter cette action
     * - La recette n'existe pas
     * - Une erreur est survenue lors de la suppression dans la base de données
     * <p>
     * Modèle de la page:
     * - error: Contient le message d'erreur, s'il y a lieu
     * - recipeCode: Contient la couleur de la recette
     * <p>
     * REQUIERT UNE AUTORISATION
     *
     * @param model    Le Model injecté par Thymeleaf
     * @param recipeID L'identifiant de la recette
     * @return La page à afficher.
     */
    @PostMapping(REMOVER_RECIPE_SPECIFIC)
    public String removeRecipe(Model model, @PathVariable int recipeID) {
        Recipe recipe = recipeService.getByID(recipeID);

        // Affiche un erreur si le recette n'est pas trouvée
        if (recipe == null) {
            model.addAttribute(RESPONSE_ERROR, String.format(RECIPE_NOT_FOUND, recipeID));
            return listRecipes(model);
        }

        recipeService.deleteRecipe(recipe);

        model.addAttribute(RECIPE_CODE, recipe.getRecipeCode());
        return listRecipes(model);
    }
}
